==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersNetworkSourceIpv6Args.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkSourceIpv6Args.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property cidr A finding's CIDR value.
 */
public data class InsightFiltersNetworkSourceIpv6Args(
    public val cidr: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkSourceIpv6Args> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkSourceIpv6Args =
        com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkSourceIpv6Args.builder()
            .cidr(cidr.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersNetworkSourceIpv6Args].
 */
@PulumiTagMarker
public class InsightFiltersNetworkSourceIpv6ArgsBuilder internal constructor() {
    private var cidr: Output<String>? = null

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("lqqfdxmwtbdlboqd")
    public suspend fun cidr(`value`: Output<String>) {
        this.cidr = value
    }

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("cqhcomxattpbxhho")
    public suspend fun cidr(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cidr = mapped
    }

    internal fun build(): InsightFiltersNetworkSourceIpv6Args = InsightFiltersNetworkSourceIpv6Args(
        cidr = cidr ?: throw PulumiNullFieldException("cidr"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersNetworkSourceIpv6Args.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkSourceIpv6Args.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property cidr A finding's CIDR value.
 */
public data class InsightFiltersNetworkSourceIpv6Args(
    public val cidr: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkSourceIpv6Args> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkSourceIpv6Args =
        com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkSourceIpv6Args.builder()
            .cidr(cidr.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersNetworkSourceIpv6Args].
 */
@PulumiTagMarker
public class InsightFiltersNetworkSourceIpv6ArgsBuilder internal constructor() {
    private var cidr: Output<String>? = null

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("vjxaepyjomhmlvrb")
    public suspend fun cidr(`value`: Output<String>) {
        this.cidr = value
    }

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("lnftfwchksuypvsv")
    public suspend fun cidr(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cidr = mapped
    }

    internal fun build(): InsightFiltersNetworkSourceIpv6Args = InsightFiltersNetworkSourceIpv6Args(
        cidr = cidr ?: throw PulumiNullFieldException("cidr"),
    )
}
